.. currentmodule:: disnake_compass

Rich Button Implementation
==========================

.. automodule:: disnake_compass.impl.component.button

Classes
-------

.. attributetable:: disnake_compass.impl.component.button.RichButton

.. autoclass:: disnake_compass.impl.component.button.RichButton
    :members: disabled, emoji, label, style, as_ui_component, callback, get_factory, get_manager, make_custom_id, set_factory, set_manager
